#' @name SchwaabTb5.5.3
#' @title Modelo Cinético de uma Reação de Isomerização
#' @description Dados resultantes de um estudo sobre uma reação de
#'     isomerização. Foram registrados no estudo o tempo da reação
#'     (\code{tempo}), a temperatura sob a qual ela ocorreu
#'     (\code{temp})e a fração que restou do reagente após o tempo
#'     decorrido (\code{reag}). O interesse no estudo é relacionar a
#'     fração que restou do reagente com o tempo e temperatura da
#'     reação.
#'
#'     Para expressar tal relação existe um modelo cinético, descrito
#'     por uma cinética de primeira ordem, que representa uma reação de
#'     isomerização conforme descrito na equação abaixo
#'     \deqn{\texttt{reag}_i = \exp \left ( -(\alpha 10^{17})\,
#'     \texttt{tempo}_i \exp \left ( -\frac{\beta}{\texttt{temp}_i} 
#'     \right )\right )}
#'     em que o índice \eqn{i} representa cada realização do experimento
#'     e \eqn{\alpha} e \eqn{\beta} são parâmetros a serem estimados.
#'
#' @format Um \code{data.frame} com 41 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{tempo}}{Tempo decorrido da reação, mensurado em segundos.}
#'
#' \item{\code{temp}}{Temperatura sob a qual a reação ocorreu, mensurada
#'     na escala kelvin.}
#'
#' \item{\code{reag}}{Fração que restou do reagente após a reação.}
#' }
#'
#' @keywords RNL RM
#' @source Schwaab, M., Pinto, J. C.(2007). Análise de Dados
#'     Experimentais I. Rio de Janeiro, RJ. COPPE UFRJ e-papers.
#' @examples
#'
#' data(SchwaabTb5.5.3)
#' str(SchwaabTb5.5.3)
#'
#' library(lattice)
#' splom(~SchwaabTb5.5.3)
#'
#' # Ajuste do modelo cinético
#' model <- nls(reag ~ exp(-(alpha * 1e+17) * tempo * exp(-beta/temp)),
#'              start = list(alpha = 0.8, beta = 27500),
#'              data = SchwaabTb5.5.3)
#' summary(model)
#'
#' # Observados vs preditos
#' xyplot(SchwaabTb5.5.3$reag ~ fitted(model),
#'        type = c("g", "p", "r"),
#'        panel = function(x, y, ...) {
#'            panel.xyplot(x, y, ...)
#'            panel.abline(0, 1)
#'        })
#'
NULL
